@@ -357,6 +357,26 @@ menu_contents (void)
   return frame;
 }
 
+static void
+override_background_color (GtkWidget *widget,
+                           GdkRGBA   *rgba)
+{
+  gchar          *css;
+  GtkCssProvider *provider;
+
+  provider = gtk_css_provider_new ();
+
+  css = g_strdup_printf ("* { background-color: %s; }",
+                         gdk_rgba_to_string (rgba));
+  gtk_css_provider_load_from_data (provider, css, -1, NULL);
+  g_free (css);
+
+  gtk_style_context_add_provider (gtk_widget_get_style_context (widget),
+                                  GTK_STYLE_PROVIDER (provider),
+                                  GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+  g_object_unref (provider);
+}
+
 static GtkWidget*
 border_only_contents (void)
 {
@@ -371,7 +391,7 @@ border_only_contents (void)
   color.green = 0;
   color.blue = 0.6;
   color.alpha = 1.0;
-  gtk_widget_override_background_color (event_box, 0, &color);
+  override_background_color (event_box, &color);
 
   vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), 3);
@@ -480,6 +500,25 @@ get_window_flags (MetaFrameType type)
   return flags;
 }
 
+static void
+override_font (GtkWidget   *widget,
+               const gchar *font)
+{
+  gchar          *css;
+  GtkCssProvider *provider;
+
+  provider = gtk_css_provider_new ();
+
+  css = g_strdup_printf ("* { font: %s; }", font);
+  gtk_css_provider_load_from_data (provider, css, -1, NULL);
+  g_free (css);
+
+  gtk_style_context_add_provider (gtk_widget_get_style_context (widget),
+                                  GTK_STYLE_PROVIDER (provider),
+                                  GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+  g_object_unref (provider);
+}
+
 static GtkWidget*
 preview_collection (int font_size,
                     const PangoFontDescription *base_desc)
@@ -517,18 +556,18 @@ preview_collection (int font_size,
   desktop_color.blue = 0.65;
   desktop_color.alpha = 1.0;
 
-  gtk_widget_override_background_color (eventbox, 0, &desktop_color);
+  override_background_color (eventbox, &desktop_color);
 
   i = 0;
   while (i < META_FRAME_TYPE_LAST)
     {
       const char *title = NULL;
       GtkWidget *contents;
-      GtkWidget *align;
-      double xalign, yalign;
+      GtkAlign xalign, yalign;
       GtkWidget *eventbox2;
       GtkWidget *preview;
       PangoFontDescription *font_desc;
+      gchar *font_string;
       double scale;
 
       eventbox2 = gtk_event_box_new ();
@@ -551,19 +590,19 @@ preview_collection (int font_size,
 
       if (i == META_FRAME_TYPE_MENU)
         {
-          xalign = 0.0;
-          yalign = 0.0;
+          xalign = GTK_ALIGN_START;
+          yalign = GTK_ALIGN_START;
         }
       else
         {
-          xalign = 0.5;
-          yalign = 0.5;
+          xalign = GTK_ALIGN_FILL;
+          yalign = GTK_ALIGN_FILL;
         }
 
-      align = gtk_alignment_new (0.0, 0.0, xalign, yalign);
-      gtk_container_add (GTK_CONTAINER (align), eventbox2);
+      gtk_widget_set_halign (eventbox2, xalign);
+      gtk_widget_set_valign (eventbox2, yalign);
 
-      gtk_box_pack_start (GTK_BOX (box), align, TRUE, TRUE, 0);
+      gtk_box_pack_start (GTK_BOX (box), eventbox2, TRUE, TRUE, 0);
 
       switch (font_size)
         {
@@ -585,7 +624,9 @@ preview_collection (int font_size,
           pango_font_description_set_size (font_desc,
                                            MAX (pango_font_description_get_size (base_desc) * scale, 1));
 
-          gtk_widget_override_font (preview, font_desc);
+          font_string = pango_font_description_to_string (font_desc);
+          override_font (preview, font_string);
+          g_free (font_string);
 
           pango_font_description_free (font_desc);
         }
@@ -741,13 +782,11 @@ previews_of_button_layouts (void)
   desktop_color.blue = 0.65;
   desktop_color.alpha = 1.0;
 
-  gtk_widget_override_background_color (eventbox, 0, &desktop_color);
+  override_background_color (eventbox, &desktop_color);
 
   i = 0;
   while (i < BUTTON_LAYOUT_COMBINATIONS)
     {
-      GtkWidget *align;
-      double xalign, yalign;
       GtkWidget *eventbox2;
       GtkWidget *preview;
       char *title;
@@ -767,13 +806,9 @@ previews_of_button_layouts (void)
       meta_preview_set_button_layout (META_PREVIEW (preview),
                                       &different_layouts[i]);
 
-      xalign = 0.5;
-      yalign = 0.5;
+      gtk_widget_set_halign (eventbox2, GTK_ALIGN_FILL);
 
-      align = gtk_alignment_new (0.0, 0.0, xalign, yalign);
-      gtk_container_add (GTK_CONTAINER (align), eventbox2);
-
-      gtk_box_pack_start (GTK_BOX (box), align, TRUE, TRUE, 0);
+      gtk_box_pack_start (GTK_BOX (box), eventbox2, TRUE, TRUE, 0);
 
       previews[META_FRAME_TYPE_LAST*FONT_SIZE_LAST + i] = preview;
 
